[PATCH] aarch64: increase alias candidate limit in aarch64-gen

Muhammad Kamran muhammad.kamran@arm.com
Wed Aug 19 08:23:27 GMT 2026


Increase max_num_aliases from 32 to 64 so that aarch64-gen can
accommodate the additional HINT-space alias added for FEAT_PAuth_LR.

The generated disassembler alias preference list can otherwise exceed
the old fixed limit.
---
 opcodes/aarch64-gen.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/opcodes/aarch64-gen.c b/opcodes/aarch64-gen.c
index a387cd4a1e0..abe4147f2c4 100644
--- a/opcodes/aarch64-gen.c
+++ b/opcodes/aarch64-gen.c
@@ -789,8 +789,8 @@ opcode_node *
 find_alias_opcode (const aarch64_opcode *opcode)
 {
   int i;
-  /* Assume maximum of 32 disassemble preference candidates.  */
-  const int max_num_aliases = 32;
+  /* Assume maximum of 64 disassemble preference candidates.  */
+  const int max_num_aliases = 64;
   const aarch64_opcode *ent;
   const aarch64_opcode *preferred[max_num_aliases + 1];
   opcode_node head, **next;
-- 
2.43.0



More information about the Binutils mailing list